@@ -13,11 +13,9 @@ extern void log_descriptor_print(void *ldp);
 extern void quota_print(void *qp);
 extern void quota_change_print(void *qcp);
 extern void statfs_change_print(void *scp);
-extern void ea_header_print(void *eap);
+extern void ea_header_print(void *eap, unsigned lim);
 extern void leaf_print(void *lfp);
 extern void rindex_print(void *rip);
 extern void rgrp_print(void *rgp);
-extern void gfs_rgrp_print(void *rgp);
-extern void gfs_jindex_print(struct gfs_jindex *ji);
 
 #endif /* STRUCT_PRINT_H */
