@@ -4,7 +4,6 @@
 #include <inttypes.h>
 #include <stdlib.h>
 #include <string.h>
-#include <time.h>
 #include <unistd.h>
 #include <libintl.h>
 #define _(String) gettext(String)
@@ -111,13 +110,8 @@ static void refresh_rgrp(struct lgfs2_sbd *sdp, struct lgfs2_rgrp_tree *rgd,
 
 		memcpy(rgd->rt_bits[i].bi_data, bh->b_data, sdp->sd_bsize);
 		rgd->rt_bits[i].bi_modified = 1;
-		if (i == 0) { /* this is the rgrp itself */
-			if (sdp->gfs1)
-				lgfs2_gfs_rgrp_in(rgd,
-						  rgd->rt_bits[0].bi_data);
-			else
-				lgfs2_rgrp_in(rgd, rgd->rt_bits[0].bi_data);
-		}
+		if (i == 0) /* this is the rgrp itself */
+			lgfs2_rgrp_in(rgd, rgd->rt_bits[0].bi_data);
 		break;
 	}
 }
@@ -696,7 +690,7 @@ int replay_journals(struct fsck_cx *cx, int *clean_journals)
 
 	*clean_journals = 0;
 
-	sdp->jsize = LGFS2_DEFAULT_JSIZE;
+	cx->jnl_size = LGFS2_DEFAULT_JSIZE;
 
 	for(i = 0; i < sdp->md.journals; i++) {
 		if (sdp->md.journal[i]) {
@@ -717,9 +711,9 @@ int replay_journals(struct fsck_cx *cx, int *clean_journals)
 		if (!error) {
 			uint64_t jsize = sdp->md.journal[i]->i_size / (1024 * 1024);
 
-			if (sdp->jsize == LGFS2_DEFAULT_JSIZE && jsize &&
-			    jsize != sdp->jsize)
-				sdp->jsize = jsize;
+			if (cx->jnl_size == LGFS2_DEFAULT_JSIZE && jsize &&
+			    jsize != cx->jnl_size)
+				cx->jnl_size = jsize;
 			error = recover_journal(sdp->md.journal[i], i, cx, &clean);
 			if (!clean)
 				dirty_journals++;
@@ -750,7 +744,7 @@ int ji_update(struct lgfs2_sbd *sdp)
 {
 	struct lgfs2_inode *jip, *ip = sdp->md.jiinode;
 	char journal_name[JOURNAL_NAME_SIZE];
-	int i, error;
+	int i;
 
 	if (!ip) {
 		log_crit(_("Journal index inode not found.\n"));
@@ -761,9 +755,7 @@ int ji_update(struct lgfs2_sbd *sdp)
 	   plus two for "." and "..".  So we subtract the 2 and divide by 3.
 	   If per_node is missing or damaged, we have to trust jindex has
 	   the correct number of entries. */
-	if (sdp->gfs1)
-		sdp->md.journals = ip->i_size / sizeof(struct gfs_jindex);
-	else if (sdp->md.pinode) /* if per_node was read in properly */
+	if (sdp->md.pinode) /* if per_node was read in properly */
 		sdp->md.journals = (sdp->md.pinode->i_entries - 2) / 3;
 	else
 		sdp->md.journals = ip->i_entries - 2;
@@ -775,28 +767,11 @@ int ji_update(struct lgfs2_sbd *sdp)
 	}
 	memset(journal_name, 0, sizeof(*journal_name));
 	for (i = 0; i < sdp->md.journals; i++) {
-		if (sdp->gfs1) {
-			struct gfs_jindex ji;
-
-			error = lgfs2_readi(ip, &ji, i * sizeof(struct gfs_jindex),
-			                    sizeof(struct gfs_jindex));
-			if (!error)
-				break;
-			if (error != sizeof(struct gfs_jindex)){
-				log_err(_("An error occurred while reading the"
-					" journal index file.\n"));
-				return -1;
-			}
-			sdp->md.journal[i] = lgfs2_inode_read(sdp, be64_to_cpu(ji.ji_addr));
-			if (sdp->md.journal[i] == NULL)
-				return -1;
-		} else {
-			/* FIXME check snprintf return code */
-			int len;
-			len = snprintf(journal_name, JOURNAL_NAME_SIZE, "journal%u", i);
-			jip = lgfs2_lookupi(sdp->md.jiinode, journal_name, len);
-			sdp->md.journal[i] = jip;
-		}
+		/* FIXME check snprintf return code */
+		int len;
+		len = snprintf(journal_name, JOURNAL_NAME_SIZE, "journal%u", i);
+		jip = lgfs2_lookupi(sdp->md.jiinode, journal_name, len);
+		sdp->md.journal[i] = jip;
 	}
 	return 0;
 }
@@ -855,8 +830,9 @@ static struct metawalk_fxns jindex_check_fxns = {
 	.check_dentry = check_jindex_dent,
 };
 
-int build_jindex(struct lgfs2_sbd *sdp)
+int build_jindex(struct fsck_cx *cx)
 {
+	struct lgfs2_sbd *sdp = cx->sdp;
 	struct lgfs2_inode *jindex;
 
 	jindex = lgfs2_createi(sdp->master_dir, "jindex", S_IFDIR | 0700,
@@ -870,7 +846,7 @@ int build_jindex(struct lgfs2_sbd *sdp)
 		return ENOSPC;
 	}
 	for (unsigned j = 0; j < sdp->md.journals; j++) {
-		int ret = lgfs2_build_journal(sdp, j, jindex);
+		int ret = lgfs2_build_journal(sdp, j, jindex, cx->jnl_size);
 		if (ret)
 			return ret;
 		lgfs2_inode_put(&sdp->md.journal[j]);
@@ -883,15 +859,13 @@ int build_jindex(struct lgfs2_sbd *sdp)
 int init_jindex(struct fsck_cx *cx, int allow_ji_rebuild)
 {
 	struct lgfs2_sbd *sdp = cx->sdp;
+	int error;
 
 	log_debug(_("Validating the journal index.\n"));
 	/* rgrepair requires the journals be read in in order to distinguish
 	   "real" rgrps from rgrps that are just copies left in journals. */
-	if (sdp->gfs1)
-		sdp->md.jiinode = lgfs2_inode_read(sdp, sdp->sd_jindex_di.in_addr);
-	else
-		/* coverity[identity_transfer:SUPPRESS] */
-		sdp->md.jiinode = lgfs2_lookupi(sdp->master_dir, "jindex", 6);
+	/* coverity[identity_transfer:SUPPRESS] */
+	sdp->md.jiinode = lgfs2_lookupi(sdp->master_dir, "jindex", 6);
 
 	if (!sdp->md.jiinode) {
 		int err;
@@ -908,7 +882,7 @@ int init_jindex(struct fsck_cx *cx, int allow_ji_rebuild)
 			return -1;
 		}
 
-		err = build_jindex(sdp);
+		err = build_jindex(cx);
 		if (err) {
 			log_crit(_("Error %d rebuilding jindex\n"), err);
 			return err;
@@ -919,36 +893,33 @@ int init_jindex(struct fsck_cx *cx, int allow_ji_rebuild)
 
 	/* check for irrelevant entries in jindex. Can't use check_dir because
 	   that creates and destroys the inode, which we don't want. */
-	if (!sdp->gfs1) {
-		int error;
 
-		log_debug(_("Checking the integrity of the journal index.\n"));
-		if (sdp->md.jiinode->i_flags & GFS2_DIF_EXHASH)
-			error = check_leaf_blks(cx, sdp->md.jiinode,
-						&jindex_check_fxns);
-		else
-			error = check_linear_dir(cx, sdp->md.jiinode,
-						 sdp->md.jiinode->i_bh,
-						 &jindex_check_fxns);
-		if (error) {
-			log_err(_("The system journal index is damaged.\n"));
-			if (!query(cx, _("Okay to rebuild it? (y/n) "))) {
-				log_crit(_("Error: cannot proceed without a "
-					   "valid jindex file.\n"));
-				return -1;
-			}
-			lgfs2_inode_put(&sdp->md.jiinode);
-			lgfs2_dirent_del(sdp->master_dir, "jindex", 6);
-			log_err(_("Corrupt journal index was removed.\n"));
-			error = build_jindex(sdp);
-			if (error) {
-				log_err(_("Error rebuilding journal "
-					  "index: Cannot continue.\n"));
-				return error;
-			}
-			/* coverity[pass_freed_arg:SUPPRESS] */
-			sdp->md.jiinode = lgfs2_lookupi(sdp->master_dir, "jindex", 6);
+	log_debug(_("Checking the integrity of the journal index.\n"));
+	if (sdp->md.jiinode->i_flags & GFS2_DIF_EXHASH)
+		error = check_leaf_blks(cx, sdp->md.jiinode,
+					&jindex_check_fxns);
+	else
+		error = check_linear_dir(cx, sdp->md.jiinode,
+					 sdp->md.jiinode->i_bh,
+					 &jindex_check_fxns);
+	if (error) {
+		log_err(_("The system journal index is damaged.\n"));
+		if (!query(cx, _("Okay to rebuild it? (y/n) "))) {
+			log_crit(_("Error: cannot proceed without a "
+				   "valid jindex file.\n"));
+			return -1;
 		}
+		lgfs2_inode_put(&sdp->md.jiinode);
+		lgfs2_dirent_del(sdp->master_dir, "jindex", 6);
+		log_err(_("Corrupt journal index was removed.\n"));
+		error = build_jindex(cx);
+		if (error) {
+			log_err(_("Error rebuilding journal "
+				  "index: Cannot continue.\n"));
+			return error;
+		}
+		/* coverity[pass_freed_arg:SUPPRESS] */
+		sdp->md.jiinode = lgfs2_lookupi(sdp->master_dir, "jindex", 6);
 	}
 
 	/* read in the ji data */
