@@ -122,6 +122,7 @@ struct fsck_cx {
 	struct osi_root dirtree;
 	struct osi_root inodetree;
 	const struct fsck_options * const opts;
+	unsigned int jnl_size;
 };
 
 extern struct lgfs2_inode *fsck_load_inode(struct lgfs2_sbd *sdp, uint64_t block);
@@ -204,6 +205,8 @@ extern struct special_blocks *blockfind(struct special_blocks *blist, uint64_t n
 extern void special_set(struct special_blocks *blocklist, uint64_t block);
 extern void special_free(struct special_blocks *blist);
 extern int sb_fixed;
-extern int build_per_node(struct lgfs2_sbd *sdp);
+extern int build_per_node(struct fsck_cx *cx);
+extern int build_metadir(struct fsck_cx *cx);
+extern int build_root(struct fsck_cx *cx);
 
 #endif /* _FSCK_H */
