@@ -17,11 +17,11 @@
 #include "metawalk.h"
 #include "util.h"
 
-const char *reftypes[ref_types + 1] = {"data", "metadata",
+const char *reftypes[REF_TYPES + 1] = {"data", "metadata",
 				       "an extended attribute", "an inode",
 				       "unimportant"};
 
-void big_file_comfort(struct gfs2_inode *ip, uint64_t blks_checked)
+void big_file_comfort(struct fsck_cx *cx, struct lgfs2_inode *ip, uint64_t blks_checked)
 {
 	static struct timeval tv;
 	static uint32_t seconds = 0;
@@ -30,7 +30,7 @@ void big_file_comfort(struct gfs2_inode *ip, uint64_t blks_checked)
 	int i, cs;
 	const char *human_abbrev = " KMGTPE";
 
-	one_percent = ip->i_di.di_blocks / 100;
+	one_percent = ip->i_blocks / 100;
 	if (blks_checked - last_reported_fblock < one_percent)
 		return;
 
@@ -41,27 +41,22 @@ void big_file_comfort(struct gfs2_inode *ip, uint64_t blks_checked)
 	if (tv.tv_sec == seconds)
 		return;
 
-	fsize = ip->i_di.di_size;
+	fsize = ip->i_size;
 	for (i = 0; i < 6 && fsize > 1024; i++)
 		fsize /= 1024;
-	chksize = blks_checked * ip->i_sbd->bsize;
+	chksize = blks_checked * ip->i_sbd->sd_bsize;
 	for (cs = 0; cs < 6 && chksize > 1024; cs++)
 		chksize /= 1024;
 	seconds = tv.tv_sec;
-	percent = (blks_checked * 100) / ip->i_di.di_blocks;
-	log_notice( _("\rChecking %lld%c of %lld%c of file at %lld (0x%llx)"
-		      "- %llu percent complete.                   \r"),
-		    (long long)chksize, human_abbrev[cs],
-		    (unsigned long long)fsize, human_abbrev[i],
-		    (unsigned long long)ip->i_di.di_num.no_addr,
-		    (unsigned long long)ip->i_di.di_num.no_addr,
-		    (unsigned long long)percent);
+	percent = (blks_checked * 100) / ip->i_blocks;
+	log_notice(_("\rChecking %"PRIu64"%c of %"PRIu64"%c of file at %"PRIu64" (0x%"PRIx64")"
+		      "- %"PRIu64" percent complete.                   \r"),
+	           chksize, human_abbrev[cs], fsize, human_abbrev[i], ip->i_num.in_addr,
+	           ip->i_num.in_addr, percent);
 	fflush(stdout);
 }
 
-/* Put out a warm, fuzzy message every second so the user     */
-/* doesn't think we hung.  (This may take a long time).       */
-void warm_fuzzy_stuff(uint64_t block)
+void display_progress(uint64_t block)
 {
 	static uint64_t one_percent = 0;
 	static struct timeval tv;
@@ -81,15 +76,14 @@ void warm_fuzzy_stuff(uint64_t block)
 			seconds = tv.tv_sec;
 			if (last_fs_block) {
 				percent = (block * 100) / last_fs_block;
-				log_notice( _("\r%llu percent complete.\r"),
-					   (unsigned long long)percent);
+				log_notice(_("\r%"PRIu64" percent complete.\r"), percent);
 				fflush(stdout);
 			}
 		}
 	}
 }
 
-char gfs2_getch(void)
+char fsck_getch(void)
 {
 	struct termios termattr, savetermattr;
 	char ch;
@@ -151,7 +145,7 @@ char generic_interrupt(const char *caller, const char *where,
 
 		/* Make sure query is printed out */
 		fflush(NULL);
-		response = gfs2_getch();
+		response = fsck_getch();
 		printf("\n");
 		fflush(NULL);
 		if (strchr(answers, response))
@@ -166,7 +160,7 @@ char generic_interrupt(const char *caller, const char *where,
 
 /* fsck_query: Same as gfs2_query except it adjusts errors_found and
    errors_corrected. */
-int fsck_query(const char *format, ...)
+int fsck_query(struct fsck_cx *cx, const char *format, ...)
 {
 	va_list args;
 	char response;
@@ -174,14 +168,13 @@ int fsck_query(const char *format, ...)
 
 	errors_found++;
 	fsck_abort = 0;
-	if (opts.yes) {
+	if (cx->opts->yes) {
 		errors_corrected++;
 		return 1;
 	}
-	if (opts.no)
+	if (cx->opts->no)
 		return 0;
 
-	opts.query = 1;
 	while (1) {
 		va_start(args, format);
 		vprintf(format, args);
@@ -189,7 +182,7 @@ int fsck_query(const char *format, ...)
 
 		/* Make sure query is printed out */
 		fflush(NULL);
-		response = gfs2_getch();
+		response = fsck_getch();
 
 		printf("\n");
 		fflush(NULL);
@@ -217,22 +210,20 @@ int fsck_query(const char *format, ...)
 			       response);
 		}
 	}
-
-	opts.query = 0;
 	return ret;
 }
 
 /*
- * gfs2_dup_set - Flag a block as a duplicate
+ * dup_set - Flag a block as a duplicate
  * We keep the references in a red/black tree.  We can't keep track of every
  * single inode in the file system, so the first time this function is called
  * will actually be for the second reference to the duplicated block.
  * This will return the number of references to the block.
  *
  * create - will be set if the call is supposed to create the reference. */
-static struct duptree *gfs2_dup_set(uint64_t dblock, int create)
+static struct duptree *dup_set(struct fsck_cx *cx, uint64_t dblock, int create)
 {
-	struct osi_node **newn = &dup_blocks.osi_node, *parent = NULL;
+	struct osi_node **newn = &cx->dup_blocks.osi_node, *parent = NULL;
 	struct duptree *dt;
 
 	/* Figure out where to put new node */
@@ -264,7 +255,7 @@ static struct duptree *gfs2_dup_set(uint64_t dblock, int create)
 	osi_list_init(&dt->ref_inode_list);
 	osi_list_init(&dt->ref_invinode_list);
 	osi_link_node(&dt->node, parent, newn);
-	osi_insert_color(&dt->node, &dup_blocks);
+	osi_insert_color(&dt->node, &cx->dup_blocks);
 
 	return dt;
 }
@@ -273,7 +264,7 @@ static struct duptree *gfs2_dup_set(uint64_t dblock, int create)
  * find_dup_ref_inode - find a duplicate reference inode entry for an inode
  */
 struct inode_with_dups *find_dup_ref_inode(struct duptree *dt,
-					   struct gfs2_inode *ip)
+					   struct lgfs2_inode *ip)
 {
 	osi_list_t *ref;
 	struct inode_with_dups *id;
@@ -281,13 +272,13 @@ struct inode_with_dups *find_dup_ref_inode(struct duptree *dt,
 	osi_list_foreach(ref, &dt->ref_invinode_list) {
 		id = osi_list_entry(ref, struct inode_with_dups, list);
 
-		if (id->block_no == ip->i_di.di_num.no_addr)
+		if (id->block_no == ip->i_num.in_addr)
 			return id;
 	}
 	osi_list_foreach(ref, &dt->ref_inode_list) {
 		id = osi_list_entry(ref, struct inode_with_dups, list);
 
-		if (id->block_no == ip->i_di.di_num.no_addr)
+		if (id->block_no == ip->i_num.in_addr)
 			return id;
 	}
 	return NULL;
@@ -304,12 +295,12 @@ int count_dup_meta_refs(struct duptree *dt)
 
 	osi_list_foreach(ref, &dt->ref_invinode_list) {
 		id = osi_list_entry(ref, struct inode_with_dups, list);
-		if (id->reftypecount[ref_as_meta])
+		if (id->reftypecount[REF_AS_META])
 			metarefs++;
 	}
 	osi_list_foreach(ref, &dt->ref_inode_list) {
 		id = osi_list_entry(ref, struct inode_with_dups, list);
-		if (id->reftypecount[ref_as_meta])
+		if (id->reftypecount[REF_AS_META])
 			metarefs++;
 	}
 	return metarefs;
@@ -329,26 +320,26 @@ int count_dup_meta_refs(struct duptree *dt)
  *         called from pass1, which is the second reference, which determined
  *         it was a duplicate..
  */
-int add_duplicate_ref(struct gfs2_inode *ip, uint64_t block,
+int add_duplicate_ref(struct fsck_cx *cx, struct lgfs2_inode *ip, uint64_t block,
 		      enum dup_ref_type reftype, int first, int inode_valid)
 {
 	struct inode_with_dups *id;
 	struct duptree *dt;
 
 	if (!valid_block_ip(ip, block))
-		return meta_is_good;
+		return META_IS_GOOD;
 	/* If this is not the first reference (i.e. all calls from pass1) we
 	   need to create the duplicate reference. If this is pass1b, we want
 	   to ignore references that aren't found. */
-	dt = gfs2_dup_set(block, !first);
+	dt = dup_set(cx, block, !first);
 	if (!dt)        /* If this isn't a duplicate */
-		return meta_is_good;
+		return META_IS_GOOD;
 
 	/* If we found the duplicate reference but we've already discovered
 	   the first reference (in pass1b) and the other references in pass1,
 	   we don't need to count it, so just return. */
 	if (dt->dup_flags & DUPFLAG_REF1_FOUND)
-		return meta_is_good;
+		return META_IS_GOOD;
 
 	/* Check for a previous reference to this duplicate */
 	id = find_dup_ref_inode(dt, ip);
@@ -360,15 +351,13 @@ int add_duplicate_ref(struct gfs2_inode *ip, uint64_t block,
 	   reference the same as the first. If we do, we'll never be able to
 	   resolve it. The first reference can't be the second reference. */
 	if (id && first && !(dt->dup_flags & DUPFLAG_REF1_FOUND)) {
-		log_info(_("Original reference to block %llu (0x%llx) was "
+		log_info(_("Original reference to block %"PRIu64" (0x%"PRIx64") was "
 			   "either found to be bad and deleted, or else "
 			   "a duplicate within the same inode.\n"),
-			 (unsigned long long)block,
-			 (unsigned long long)block);
-		log_info(_("I'll consider the reference from inode %llu "
-			   "(0x%llx) the first reference.\n"),
-			 (unsigned long long)ip->i_di.di_num.no_addr,
-			 (unsigned long long)ip->i_di.di_num.no_addr);
+		         block, block);
+		log_info(_("I'll consider the reference from inode %"PRIu64
+			   " (0x%"PRIx64") the first reference.\n"),
+		         ip->i_num.in_addr, ip->i_num.in_addr);
 		dt->dup_flags |= DUPFLAG_REF1_IS_DUPL;
 		dt->refs++;
 	}
@@ -391,10 +380,10 @@ int add_duplicate_ref(struct gfs2_inode *ip, uint64_t block,
 		id = calloc(1, sizeof(*id));
 		if (!id) {
 			log_crit( _("Unable to allocate inode_with_dups structure\n"));
-			return meta_error;
+			return META_ERROR;
 		}
-		id->block_no = ip->i_di.di_num.no_addr;
-		q = bitmap_type(ip->i_sbd, ip->i_di.di_num.no_addr);
+		id->block_no = ip->i_num.in_addr;
+		q = bitmap_type(ip->i_sbd, ip->i_num.in_addr);
 		/* If it's an invalid dinode, put it first on the invalid
 		   inode reference list otherwise put it on the normal list. */
 		if (!inode_valid || q == GFS2_BLKST_UNLINKED)
@@ -414,13 +403,11 @@ int add_duplicate_ref(struct gfs2_inode *ip, uint64_t block,
 	}
 	id->reftypecount[reftype]++;
 	id->dup_count++;
-	log_info( _("Found %d reference(s) to block %llu"
-		    " (0x%llx) as %s in %s inode #%llu (0x%llx)\n"),
-		  id->dup_count, (unsigned long long)block,
-		  (unsigned long long)block, reftypes[reftype],
+	log_info(_("Found %d reference(s) to block %"PRIu64" (0x%"PRIx64") "
+	           "as %s in %s inode #%"PRIu64" (0x%"PRIx64")\n"),
+		  id->dup_count, block, block, reftypes[reftype],
 		  inode_valid ? _("valid") : _("invalid"),
-		  (unsigned long long)ip->i_di.di_num.no_addr,
-		  (unsigned long long)ip->i_di.di_num.no_addr);
+		  ip->i_num.in_addr, ip->i_num.in_addr);
 	if (first)
 		log_info( _("This is the original reference.\n"));
 	else {
@@ -431,12 +418,12 @@ int add_duplicate_ref(struct gfs2_inode *ip, uint64_t block,
 			    "%d from this inode.\n"),
 			  dt->refs, id->dup_count);
 	}
-	return meta_is_good;
+	return META_IS_GOOD;
 }
 
-struct dir_info *dirtree_insert(struct gfs2_inum inum)
+struct dir_info *dirtree_insert(struct fsck_cx *cx, struct lgfs2_inum inum)
 {
-	struct osi_node **newn = &dirtree.osi_node, *parent = NULL;
+	struct osi_node **newn = &cx->dirtree.osi_node, *parent = NULL;
 	struct dir_info *data;
 
 	/* Figure out where to put new node */
@@ -444,9 +431,9 @@ struct dir_info *dirtree_insert(struct gfs2_inum inum)
 		struct dir_info *cur = (struct dir_info *)*newn;
 
 		parent = *newn;
-		if (inum.no_addr < cur->dinode.no_addr)
+		if (inum.in_addr < cur->dinode.in_addr)
 			newn = &((*newn)->osi_left);
-		else if (inum.no_addr > cur->dinode.no_addr)
+		else if (inum.in_addr > cur->dinode.in_addr)
 			newn = &((*newn)->osi_right);
 		else
 			return cur;
@@ -458,24 +445,24 @@ struct dir_info *dirtree_insert(struct gfs2_inum inum)
 		return NULL;
 	}
 	/* Add new node and rebalance tree. */
-	data->dinode.no_addr = inum.no_addr;
-	data->dinode.no_formal_ino = inum.no_formal_ino;
+	data->dinode.in_addr = inum.in_addr;
+	data->dinode.in_formal_ino = inum.in_formal_ino;
 	osi_link_node(&data->node, parent, newn);
-	osi_insert_color(&data->node, &dirtree);
+	osi_insert_color(&data->node, &cx->dirtree);
 
 	return data;
 }
 
-struct dir_info *dirtree_find(uint64_t block)
+struct dir_info *dirtree_find(struct fsck_cx *cx, uint64_t block)
 {
-	struct osi_node *node = dirtree.osi_node;
+	struct osi_node *node = cx->dirtree.osi_node;
 
 	while (node) {
 		struct dir_info *data = (struct dir_info *)node;
 
-		if (block < data->dinode.no_addr)
+		if (block < data->dinode.in_addr)
 			node = node->osi_left;
-		else if (block > data->dinode.no_addr)
+		else if (block > data->dinode.in_addr)
 			node = node->osi_right;
 		else
 			return data;
@@ -491,10 +478,10 @@ enum dup_ref_type get_ref_type(struct inode_with_dups *id)
 	int found_type_with_ref;
 	int found_other_types;
 
-	for (t = ref_as_data; t < ref_types; t++) {
+	for (t = REF_AS_DATA; t < REF_TYPES; t++) {
 		found_type_with_ref = 0;
 		found_other_types = 0;
-		for (i = ref_as_data; i < ref_types; i++) {
+		for (i = REF_AS_DATA; i < REF_TYPES; i++) {
 			if (id->reftypecount[i]) {
 				if (t == i)
 					found_type_with_ref = 1;
@@ -503,26 +490,24 @@ enum dup_ref_type get_ref_type(struct inode_with_dups *id)
 			}
 		}
 		if (found_type_with_ref)
-			return found_other_types ? ref_types : t;
+			return found_other_types ? REF_TYPES : t;
 	}
-	return ref_types;
+	return REF_TYPES;
 }
 
 void dup_listent_delete(struct duptree *dt, struct inode_with_dups *id)
 {
-	log_err( _("Removing duplicate reference to block %llu (0x%llx) "
-		   "referenced as %s by dinode %llu (0x%llx)\n"),
-		 (unsigned long long)dt->block, (unsigned long long)dt->block,
-		 reftypes[get_ref_type(id)], (unsigned long long)id->block_no,
-		 (unsigned long long)id->block_no);
-	dt->refs--; /* one less reference */
+	log_err(_("Removing duplicate reference to block %"PRIu64" (0x%"PRIx64") "
+	          "referenced as %s by dinode %"PRIu64" (0x%"PRIx64")\n"),
+	        dt->block, dt->block, reftypes[get_ref_type(id)], id->block_no, id->block_no);
+	dt->refs--;
 	if (id->name)
 		free(id->name);
 	osi_list_del(&id->list);
 	free(id);
 }
 
-void dup_delete(struct duptree *dt)
+void dup_delete(struct fsck_cx *cx, struct duptree *dt)
 {
 	struct inode_with_dups *id;
 	osi_list_t *tmp;
@@ -537,21 +522,20 @@ void dup_delete(struct duptree *dt)
 		id = osi_list_entry(tmp, struct inode_with_dups, list);
 		dup_listent_delete(dt, id);
 	}
-	osi_erase(&dt->node, &dup_blocks);
+	osi_erase(&dt->node, &cx->dup_blocks);
 	free(dt);
 }
 
-void dirtree_delete(struct dir_info *b)
+void dirtree_delete(struct fsck_cx *cx, struct dir_info *b)
 {
-	osi_erase(&b->node, &dirtree);
+	osi_erase(&b->node, &cx->dirtree);
 	free(b);
 }
 
-uint64_t find_free_blk(struct gfs2_sbd *sdp)
+uint64_t find_free_blk(struct lgfs2_sbd *sdp)
 {
 	struct osi_node *n, *next = NULL;
-	struct rgrp_tree *rl = NULL;
-	struct gfs2_rindex *ri;
+	struct lgfs2_rgrp_tree *rl = NULL;
 	struct gfs2_rgrp *rg;
 	unsigned int block, bn = 0, x = 0, y = 0;
 	unsigned int state;
@@ -559,42 +543,39 @@ uint64_t find_free_blk(struct gfs2_sbd *sdp)
 	memset(&rg, 0, sizeof(rg));
 	for (n = osi_first(&sdp->rgtree); n; n = next) {
 		next = osi_next(n);
-		rl = (struct rgrp_tree *)n;
-		if (rl->rg.rg_free)
+		rl = (struct lgfs2_rgrp_tree *)n;
+		if (rl->rt_free)
 			break;
 	}
 
 	if (n == NULL)
 		return 0;
 
-	ri = &rl->ri;
-	rg = &rl->rg;
-
-	for (block = 0; block < ri->ri_length; block++) {
-		char *buf = rl->bits[block].bi_data;
+	for (block = 0; block < rl->rt_length; block++) {
+		char *buf = rl->rt_bits[block].bi_data;
 		x = (block) ? sizeof(struct gfs2_meta_header) : sizeof(struct gfs2_rgrp);
 
-		for (; x < sdp->bsize; x++)
+		for (; x < sdp->sd_bsize; x++)
 			for (y = 0; y < GFS2_NBBY; y++) {
 				state = (buf[x] >> (GFS2_BIT_SIZE * y)) & 0x03;
 				if (state == GFS2_BLKST_FREE)
-					return ri->ri_data0 + bn;
+					return rl->rt_data0 + bn;
 				bn++;
 			}
 	}
 	return 0;
 }
 
-uint64_t *get_dir_hash(struct gfs2_inode *ip)
+__be64 *get_dir_hash(struct lgfs2_inode *ip)
 {
-	unsigned hsize = (1 << ip->i_di.di_depth) * sizeof(uint64_t);
+	unsigned hsize = (1 << ip->i_depth) * sizeof(uint64_t);
 	int ret;
-	uint64_t *tbl = malloc(hsize);
+	__be64 *tbl = malloc(hsize);
 
 	if (tbl == NULL)
 		return NULL;
 
-	ret = gfs2_readi(ip, tbl, 0, hsize);
+	ret = lgfs2_readi(ip, tbl, 0, hsize);
 	if (ret != hsize) {
 		free(tbl);
 		return NULL;
@@ -603,7 +584,7 @@ uint64_t *get_dir_hash(struct gfs2_inode *ip)
 	return tbl;
 }
 
-void delete_all_dups(struct gfs2_inode *ip)
+void delete_all_dups(struct fsck_cx *cx, struct lgfs2_inode *ip)
 {
 	struct osi_node *n, *next;
 	struct duptree *dt;
@@ -611,7 +592,7 @@ void delete_all_dups(struct gfs2_inode *ip)
 	struct inode_with_dups *id;
 	int found;
 
-	for (n = osi_first(&dup_blocks); n; n = next) {
+	for (n = osi_first(&cx->dup_blocks); n; n = next) {
 		next = osi_next(n);
 		dt = (struct duptree *)n;
 
@@ -620,14 +601,14 @@ void delete_all_dups(struct gfs2_inode *ip)
 
 		osi_list_foreach_safe(tmp, &dt->ref_invinode_list, x) {
 			id = osi_list_entry(tmp, struct inode_with_dups, list);
-			if (id->block_no == ip->i_di.di_num.no_addr) {
+			if (id->block_no == ip->i_num.in_addr) {
 				dup_listent_delete(dt, id);
 				found = 1;
 			}
 		}
 		osi_list_foreach_safe(tmp, &dt->ref_inode_list, x) {
 			id = osi_list_entry(tmp, struct inode_with_dups, list);
-			if (id->block_no == ip->i_di.di_num.no_addr) {
+			if (id->block_no == ip->i_num.in_addr) {
 				dup_listent_delete(dt, id);
 				found = 1;
 			}
@@ -636,13 +617,13 @@ void delete_all_dups(struct gfs2_inode *ip)
 			continue;
 
 		if (dt->refs == 0) {
-			log_debug(_("This was the last reference: 0x%llx is "
+			log_debug(_("This was the last reference: 0x%"PRIx64" is "
 				    "no longer a duplicate.\n"),
-				  (unsigned long long)dt->block);
-			dup_delete(dt); /* not duplicate now */
+			          dt->block);
+			dup_delete(cx, dt);
 		} else {
-			log_debug(_("%d references remain to 0x%llx\n"),
-				  dt->refs, (unsigned long long)dt->block);
+			log_debug(_("%d references remain to 0x%"PRIx64"\n"),
+				  dt->refs, dt->block);
 			if (dt->refs > 1)
 				continue;
 
@@ -656,9 +637,8 @@ void delete_all_dups(struct gfs2_inode *ip)
 						    struct inode_with_dups,
 						    list);
 			if (id)
-				log_debug("Last reference is from inode "
-					  "0x%llx\n",
-					  (unsigned long long)id->block_no);
+				log_debug("Last reference is from inode 0x%"PRIx64"\n",
+				          id->block_no);
 		}
 	}
 }
