@@ -16,7 +16,6 @@
 #include <dirent.h>
 #include <curses.h>
 #include <term.h>
-#include <sys/time.h>
 #include <string.h>
 #include <stdint.h>
 #include <inttypes.h>
@@ -143,42 +142,41 @@ enum summary_types {
 	stypes = 7,
 };
 
-char *debugfs;
-int termcols = 80, termlines = 30, done = 0;
-unsigned glocks = 0;
-const char *termtype;
-WINDOW *wind;
-int bufsize = 4 * 1024 * 1024;
-char *glock[MAX_GLOCKS];
-int iterations = 0, show_reservations = 0, iters_done = 0;
+static char *debugfs;
+static int termcols = 80, termlines = 30, done = 0;
+static unsigned glocks = 0;
+static const char *termtype;
+static WINDOW *wind;
+static int bufsize = 4 * 1024 * 1024;
+static char *glock[MAX_GLOCKS];
+static int iterations = 0, show_reservations = 0, iters_done = 0;
 struct mount_point {
 	struct mount_point *next;
 	char *device;
 	char *dir;
 	int fd;
-	struct gfs2_sb sb;
+	struct lgfs2_sbd sb;
 };
-struct mount_point *mounts;
-char dlmwlines[MAX_LINES][96]; /* waiters lines */
-char dlmglines[MAX_LINES][97]; /* granted lines */
-char contended_filenames[MAX_FILES][PATH_MAX];
-unsigned long long contended_blocks[MAX_FILES];
-int contended_count = 0;
-int line = 0;
-const char *prog_name;
-char dlm_dirtbl_size[32], dlm_rsbtbl_size[32], dlm_lkbtbl_size[32];
-int bsize = 0;
-char print_dlm_grants = 1;
-char *gbuf = NULL; /* glocks buffer */
-char *gpos = NULL;
-char *gnextpos = NULL;
-int gmaxpos = 0;
-
-char *dbuf = NULL; /* dlm locks buffer */
-char *dpos = NULL;
-char *dnextpos = NULL;
-int dmaxpos = 0;
-char hostname[256];
+static struct mount_point *mounts;
+static char dlmwlines[MAX_LINES][96]; /* waiters lines */
+static char dlmglines[MAX_LINES][97]; /* granted lines */
+static char contended_filenames[MAX_FILES][PATH_MAX];
+static uint64_t contended_blocks[MAX_FILES];
+static int contended_count = 0;
+static int line = 0;
+static const char *prog_name;
+static char dlm_dirtbl_size[32], dlm_rsbtbl_size[32], dlm_lkbtbl_size[32];
+static int bsize = 0;
+static char print_dlm_grants = 1;
+static char *gbuf = NULL; /* glocks buffer */
+static char *gpos = NULL;
+static char *gnextpos = NULL;
+static int gmaxpos = 0;
+static char *dbuf = NULL; /* dlm locks buffer */
+static char *dpos = NULL;
+static char *dnextpos = NULL;
+static int dmaxpos = 0;
+static char hostname[256];
 
 /*
  * init_colors
@@ -223,7 +221,7 @@ static void UpdateSize(int sig)
 	signal(SIGWINCH, UpdateSize);
 }
 
-static int read_superblock(int fd, struct gfs2_sb *sb)
+static int read_superblock(int fd, struct lgfs2_sbd *sdp)
 {
 	ssize_t r;
 	char *buf;
@@ -240,10 +238,10 @@ static int read_superblock(int fd, struct gfs2_sb *sb)
 		free(buf);
 		return -1;
 	}
-	gfs2_sb_in(sb, buf);
+	lgfs2_sb_in(sdp, buf);
 	free(buf);
 
-	bsize = sb->sb_bsize;
+	bsize = sdp->sd_bsize;
 	if (!bsize)
 		bsize = 4096;
 	return 0;
@@ -551,7 +549,8 @@ static void eol(int col) /* end of line */
 	}
 }
 
-void print_it(const char *label, const char *fmt, const char *fmt2, ...)
+__attribute__((format(printf,2,4)))
+static void print_it(const char *label, const char *fmt, const char *fmt2, ...)
 {
 	va_list args;
 	char tmp_string[128];
@@ -572,8 +571,7 @@ void print_it(const char *label, const char *fmt, const char *fmt2, ...)
 	va_end(args);
 }
 
-static void display_filename(int fd, unsigned long long block,
-			     unsigned long long dirarray[256], int subdepth)
+static void display_filename(int fd, uint64_t block, uint64_t *dirarray, int subdepth)
 {
 	struct mount_point *mp;
 	int i, subs;
@@ -592,7 +590,7 @@ static void display_filename(int fd, unsigned long long block,
 			break;
 		}
 	}
-	sprintf(blk, "%lld", block);
+	sprintf(blk, "%"PRIu64, block);
 	if (i >= contended_count) {
 		memset(contended_filenames[i], 0, PATH_MAX);
 		strcat(contended_filenames[i], mp->dir);
@@ -614,59 +612,59 @@ static void display_filename(int fd, unsigned long long block,
 	eol(0);
 }
 
-static const char *show_inode(const char *id, int fd, unsigned long long block)
+static const char *show_inode(const char *id, int fd, uint64_t block)
 {
-	struct gfs2_inode *ip;
+	struct lgfs2_inode *ip;
 	const char *inode_type = NULL;
-	struct gfs2_sbd sbd = { .device_fd = fd, .bsize = bsize };
+	struct lgfs2_sbd sbd = { .device_fd = fd, .sd_bsize = bsize };
 
 	ip = lgfs2_inode_read(&sbd, block);
-	if (S_ISDIR(ip->i_di.di_mode)) {
-		struct gfs2_inode *parent;
-		unsigned long long dirarray[256];
-		int subdepth = 0, error;
+	if (S_ISDIR(ip->i_mode)) {
+		struct lgfs2_inode *parent;
+		uint64_t dirarray[256];
+		int subdepth = 0;
 
 		inode_type = "directory ";
 		dirarray[0] = block;
 		subdepth++;
 		/* Backtrack the directory to its source */
 		while (1) {
-			error = gfs2_lookupi(ip, "..", 2, &parent);
-			if (error)
+			parent = lgfs2_lookupi(ip, "..", 2);
+			if (parent == NULL)
 				break;
 			/* Stop at the root inode */
-			if (ip->i_di.di_num.no_addr ==
-			    parent->i_di.di_num.no_addr) {
-				inode_put(&parent);
+			if (ip->i_num.in_addr == parent->i_num.in_addr) {
+				lgfs2_inode_put(&parent);
 				break;
 			}
-			inode_put(&ip);
+			lgfs2_inode_put(&ip);
+			/* coverity[use_after_free:SUPPRESS] */
 			ip = parent;
-			dirarray[subdepth++] = parent->i_di.di_num.no_addr;
+			dirarray[subdepth++] = parent->i_num.in_addr;
 		}
 		display_filename(fd, block, dirarray, subdepth);
-	} else if (S_ISREG(ip->i_di.di_mode)) {
+	} else if (S_ISREG(ip->i_mode)) {
 		inode_type = "file ";
-	} else if (S_ISLNK(ip->i_di.di_mode)) {
+	} else if (S_ISLNK(ip->i_mode)) {
 		inode_type = "link ";
-	} else if (S_ISCHR(ip->i_di.di_mode)) {
+	} else if (S_ISCHR(ip->i_mode)) {
 		inode_type = "char device ";
-	} else if (S_ISBLK(ip->i_di.di_mode)) {
+	} else if (S_ISBLK(ip->i_mode)) {
 		inode_type = "block device ";
-	} else if (S_ISFIFO(ip->i_di.di_mode)) {
+	} else if (S_ISFIFO(ip->i_mode)) {
 		inode_type = "fifo ";
-	} else if (S_ISSOCK(ip->i_di.di_mode)) {
+	} else if (S_ISSOCK(ip->i_mode)) {
 		inode_type = "socket ";
 	} else
 		inode_type = "file? ";
-	inode_put(&ip);
+	lgfs2_inode_put(&ip);
 	return inode_type;
 }
 
 static const char *show_details(const char *id, const char *fsname, int btype,
 				int trace_dir_path)
 {
-	unsigned long long block = 0;
+	uint64_t block = 0;
 	const char *blk_type = NULL;
 	struct mount_point *mp;
 	FILE *dlmf;
@@ -675,7 +673,7 @@ static const char *show_details(const char *id, const char *fsname, int btype,
 	for (mp = mounts; mp != NULL; mp = mp->next) {
 		char *p;
 
-		p = strchr(mp->sb.sb_locktable, ':');
+		p = strchr(mp->sb.sd_locktable, ':');
 		if (!p)
 			continue;
 		p++;
@@ -687,7 +685,7 @@ static const char *show_details(const char *id, const char *fsname, int btype,
 	memset(dlm_dirtbl_size, 0, sizeof(dlm_dirtbl_size));
 	memset(dlm_rsbtbl_size, 0, sizeof(dlm_rsbtbl_size));
 	memset(dlm_lkbtbl_size, 0, sizeof(dlm_lkbtbl_size));
-	if (!strcmp(mp->sb.sb_lockproto, "lock_dlm")) {
+	if (!strcmp(mp->sb.sd_lockproto, "lock_dlm")) {
 		char *sp;
 		char *p;
 
@@ -734,7 +732,7 @@ static const char *show_details(const char *id, const char *fsname, int btype,
 	}
 
 	/* Read the inode in so we can see its type. */
-	sscanf(id, "%llx", &block);
+	sscanf(id, "%"PRIx64, &block);
 	if (block) {
 		if (btype == 2)
 			if (trace_dir_path)
@@ -933,7 +931,7 @@ static void show_dlm_grants(int locktype, const char *g_line, int dlmgrants,
 	char dlm_resid[75];
 	unsigned int lkb_id, lkbnodeid, remid, ownpid, exflags, flags, status;
 	unsigned int grmode, rqmode, nodeid, length;
-	unsigned long long xid, us;
+	uint64_t xid, us;
 	char trgt_res_name[64], res_name[64], *p1, *p2;
 	const char *procname;
 
@@ -962,7 +960,7 @@ lkb_id  n   remid  pid x e f s g rq u n ln res_name 1234567890123456
 		if (strncmp(dlm_resid, p1, 24))
 			continue;
 
-		sscanf(dlmglines[i], "%x %d %x %u %llu %x %x %d %d %d %llu "
+		sscanf(dlmglines[i], "%x %d %x %u %"SCNu64" %x %x %d %d %d %"SCNu64" "
 		       "%u %d \"%24s\"\n",
 		       &lkb_id, &lkbnodeid, &remid, &ownpid, &xid, &exflags,
 		       &flags, &status, &grmode, &rqmode, &us, &nodeid,
