@@ -10,7 +10,6 @@
 #include <fcntl.h>
 #include <unistd.h>
 #include <errno.h>
-#include <sys/time.h>
 #include <uuid.h>
 
 #include "libgfs2.h"
@@ -233,7 +232,7 @@ int lgfs2_write_journal(struct lgfs2_inode *jnl, unsigned bsize, unsigned int bl
 	return 0;
 }
 
-int lgfs2_build_journal(struct lgfs2_sbd *sdp, int j, struct lgfs2_inode *jindex)
+int lgfs2_build_journal(struct lgfs2_sbd *sdp, int j, struct lgfs2_inode *jindex, unsigned size_mb)
 {
 	char name[256];
 	int ret;
@@ -245,7 +244,7 @@ int lgfs2_build_journal(struct lgfs2_sbd *sdp, int j, struct lgfs2_inode *jindex
 		return errno;
 	}
 	ret = lgfs2_write_journal(sdp->md.journal[j], sdp->sd_bsize,
-	                          sdp->jsize << 20 >> sdp->sd_bsize_shift);
+	                          size_mb << 20 >> sdp->sd_bsize_shift);
 	return ret;
 }
 
@@ -318,13 +317,13 @@ struct lgfs2_inode *lgfs2_build_statfs_change(struct lgfs2_inode *per_node, unsi
 	return ip;
 }
 
-struct lgfs2_inode *lgfs2_build_quota_change(struct lgfs2_inode *per_node, unsigned int j)
+struct lgfs2_inode *lgfs2_build_quota_change(struct lgfs2_inode *per_node, unsigned int j, unsigned int size_mb)
 {
 	struct lgfs2_sbd *sdp = per_node->i_sbd;
 	struct gfs2_meta_header mh;
 	char name[256];
 	struct lgfs2_inode *ip;
-	unsigned int blocks = sdp->qcsize << (20 - sdp->sd_bsize_shift);
+	unsigned int blocks = size_mb << (20 - sdp->sd_bsize_shift);
 	unsigned int x;
 	unsigned int hgt;
 	struct lgfs2_buffer_head *bh;
