@@ -31,6 +31,7 @@
 static uint64_t override_device_size = 0;
 static int test = 0;
 static uint64_t fssize = 0, fsgrowth;
+static int skip_discard = 0;
 int print_level = MSG_NOTICE;
 
 extern int create_new_inode(struct lgfs2_sbd *sdp);
@@ -72,6 +73,7 @@ static void usage(void)
 		"-T", NULL, _("Do everything except update file system"),
 		"-V", NULL, _("Display version information"),
 		"-v", NULL, _("Increase verbosity"),
+		"-K", NULL, _("Don't try to discard unused blocks"),
 		NULL, NULL, NULL /* Must be kept at the end */
 	};
 
@@ -92,15 +94,14 @@ static void decode_arguments(int argc, char *argv[], struct lgfs2_sbd *sdp)
 {
 	int opt;
 
-	while ((opt = getopt(argc, argv, "VD:hqTv?")) != EOF) {
+	while ((opt = getopt(argc, argv, "VD:hqTv?K")) != EOF) {
 		switch (opt) {
 		case 'D':	/* This option is for testing only */
 			override_device_size = atoi(optarg);
 			override_device_size <<= 20;
 			break;
 		case 'V':
-			printf(_("%s %s (built %s %s)\n"), argv[0],
-			       VERSION, __DATE__, __TIME__);
+			printf("gfs2_grow " VERSION "\n");
 			printf(REDHAT_COPYRIGHT "\n");
 			exit(0);
 		case 'h':
@@ -117,6 +118,9 @@ static void decode_arguments(int argc, char *argv[], struct lgfs2_sbd *sdp)
 		case 'v':
 			increase_verbosity();
 			break;
+		case 'K':
+			skip_discard = 1;
+			break;
 		case ':':
 		case '?':
 			/* Unknown flag */
@@ -208,7 +212,9 @@ static unsigned initialize_new_portion(struct lgfs2_sbd *sdp, lgfs2_rgrps_t rgs)
 	unsigned rgcount = 0;
 	uint64_t rgaddr = fssize;
 
-	discard_blocks(sdp->device_fd, rgaddr * sdp->sd_bsize, fsgrowth * sdp->sd_bsize);
+	if (skip_discard == 0)
+		discard_blocks(sdp->device_fd, rgaddr * sdp->sd_bsize, fsgrowth * sdp->sd_bsize);
+
 	/* Build the remaining resource groups */
 	while (1) {
 		int err = 0;
@@ -364,9 +370,6 @@ int main(int argc, char *argv[])
 
 	memset(sdp, 0, sizeof(struct lgfs2_sbd));
 	sdp->sd_bsize = LGFS2_DEFAULT_BSIZE;
-	sdp->rgsize = -1;
-	sdp->jsize = LGFS2_DEFAULT_JSIZE;
-	sdp->qcsize = LGFS2_DEFAULT_QCSIZE;
 	sdp->md.journals = 1;
 	decode_arguments(argc, argv, sdp);
 
@@ -401,10 +404,6 @@ int main(int argc, char *argv[])
 			fprintf(stderr, _("Error reading superblock.\n"));
 			exit(EXIT_FAILURE);
 		}
-		if (sdp->gfs1) {
-			fprintf(stderr, _("cannot grow gfs1 filesystem\n"));
-			exit(EXIT_FAILURE);
-		}
 		lgfs2_fix_device_geometry(sdp);
 		mfs.context = copy_context_opt(mnt);
 		if (mount_gfs2_meta(&mfs, mnt->mnt_dir, (print_level > MSG_NOTICE))) {
