@@ -32,6 +32,8 @@ struct jadd_opts {
 	char *jindex;
 	unsigned orig_journals;
 	unsigned journals;
+	unsigned jsize;
+	unsigned qcsize;
 	unsigned quiet:1;
 	unsigned debug:1;
 };
@@ -152,7 +154,7 @@ static int decode_arguments(int argc, char *argv[], struct lgfs2_sbd *sdp, struc
 
 		switch (optchar) {
 		case 'c':
-			sdp->qcsize = atoi(optarg);
+			opts->qcsize = atoi(optarg);
 			break;
 		case 'D':
 			opts->debug = 1;
@@ -161,7 +163,7 @@ static int decode_arguments(int argc, char *argv[], struct lgfs2_sbd *sdp, struc
 			print_usage(argv[0]);
 			return 1;
 		case 'J':
-			sdp->jsize = atoi(optarg);
+			opts->jsize = atoi(optarg);
 			break;
 		case 'j':
 			opts->journals = atoi(optarg);
@@ -170,8 +172,7 @@ static int decode_arguments(int argc, char *argv[], struct lgfs2_sbd *sdp, struc
 			opts->quiet = 1;
 			break;
 		case 'V':
-			printf("gfs2_jadd %s (built %s %s)\n", VERSION,
-			       __DATE__, __TIME__);
+			printf("gfs2_jadd " VERSION "\n");
 			printf(REDHAT_COPYRIGHT "\n");
 			return 1;
 		case ':':
@@ -200,8 +201,8 @@ static int decode_arguments(int argc, char *argv[], struct lgfs2_sbd *sdp, struc
 	}
 	if (opts->debug) {
 		printf( _("Command line arguments:\n"));
-		printf("  qcsize = %u\n", sdp->qcsize);
-		printf("  jsize = %u\n", sdp->jsize);
+		printf("  qcsize = %u\n", opts->qcsize);
+		printf("  jsize = %u\n", opts->jsize);
 		printf("  journals = %u\n", sdp->md.journals);
 		printf("  quiet = %u\n", opts->quiet);
 		printf("  path = %s\n", opts->path);
@@ -215,11 +216,11 @@ static int verify_arguments(struct lgfs2_sbd *sdp, struct jadd_opts *opts)
 		fprintf(stderr, _("no journals specified\n"));
 		return -1;
 	}
-	if (sdp->jsize < 32 || sdp->jsize > 1024) {
+	if (opts->jsize < 32 || opts->jsize > 1024) {
 		fprintf(stderr, _("bad journal size\n"));
 		return -1;
 	}
-	if (!sdp->qcsize || sdp->qcsize > 64) {
+	if (!opts->qcsize || opts->qcsize > 64) {
 		fprintf(stderr, _("bad quota change size\n"));
 		return -1;
 	}
@@ -346,15 +347,20 @@ close_fd:
 static int add_qc(struct lgfs2_sbd *sdp, struct jadd_opts *opts)
 {
 	int fd, error = 0;
-	char new_name[256], buf[sdp->sd_bsize];
+	char new_name[256], *buf;
 	unsigned int blocks =
-		sdp->qcsize << (20 - sdp->sd_bsize_shift);
+		opts->qcsize << (20 - sdp->sd_bsize_shift);
 	unsigned int x;
 	struct gfs2_meta_header mh;
 
-	if ((fd = create_new_inode(opts, NULL)) < 0)
-		return fd;
+	buf = calloc(1, sdp->sd_bsize);
+	if (buf == NULL)
+		return -1;
 
+	if ((fd = create_new_inode(opts, NULL)) < 0) {
+		free(buf);
+		return fd;
+	}
 	if ((error = set_flags(fd, JA_FL_CLEAR, FS_JOURNAL_DATA_FL)))
 		goto close_fd;
 
@@ -397,6 +403,7 @@ static int add_qc(struct lgfs2_sbd *sdp, struct jadd_opts *opts)
 		goto close_fd;
 	}
 close_fd:
+	free(buf);
 	return close(fd) || error;
 }
 
@@ -514,7 +521,7 @@ static int add_j(struct lgfs2_sbd *sdp, struct jadd_opts *opts)
 {
 	int fd, error = 0;
 	char new_name[256], *buf;
-	uint32_t x, blocks = sdp->jsize << (20 - sdp->sd_bsize_shift);
+	uint32_t x, blocks = opts->jsize << (20 - sdp->sd_bsize_shift);
 	struct gfs2_log_header *lh;
 	/* Not a security sensitive use of random() */
 	/* coverity[dont_call:SUPPRESS] */
@@ -533,7 +540,7 @@ static int add_j(struct lgfs2_sbd *sdp, struct jadd_opts *opts)
 	if ((error = set_flags(fd, JA_FL_CLEAR, FS_JOURNAL_DATA_FL)))
 		goto close_fd;
 
-	error = alloc_new_journal(fd, sdp->jsize << 20);
+	error = alloc_new_journal(fd, opts->jsize << 20);
 	if (error != 0)
 		goto close_fd;
 
@@ -609,14 +616,14 @@ static int check_fit(struct lgfs2_sbd *sdp, struct jadd_opts *opts)
 	uint64_t blks_per_j, total_blks;
 
 	blks_per_j = 1 + 1 +
-		lgfs2_space_for_data(sdp, sdp->sd_bsize, sdp->qcsize << 20) +
-		lgfs2_space_for_data(sdp, sdp->sd_bsize, sdp->jsize << 20);
+		lgfs2_space_for_data(sdp, sdp->sd_bsize, opts->qcsize << 20) +
+		lgfs2_space_for_data(sdp, sdp->sd_bsize, opts->jsize << 20);
 	total_blks = opts->journals * blks_per_j;
 
 	if (total_blks > (sdp->blks_total - sdp->blks_alloced)) {
 		printf( _("\nInsufficient space on the device to add %u %uMB "
 			  "journals (%uMB QC size)\n\n"),
-			opts->journals, sdp->jsize, sdp->qcsize);
+			opts->journals, opts->jsize, opts->qcsize);
 		printf( _("Required space  : %*"PRIu64" blocks (%"PRIu64" blocks per "
 			  "journal)\n"), 10, total_blks, blks_per_j);
 		printf( _("Available space : %*"PRIu64" blocks\n\n"), 10,
@@ -641,8 +648,8 @@ int main(int argc, char *argv[])
 	srandom(time(NULL) ^ getpid());
 
 	memset(sdp, 0, sizeof(struct lgfs2_sbd));
-	sdp->jsize = LGFS2_DEFAULT_JSIZE;
-	sdp->qcsize = LGFS2_DEFAULT_QCSIZE;
+	opts.jsize = LGFS2_DEFAULT_JSIZE;
+	opts.qcsize = LGFS2_DEFAULT_QCSIZE;
 	opts.journals = 1;
 
 	ret = decode_arguments(argc, argv, sdp, &opts);
