@@ -9,14 +9,12 @@
 #include <sys/stat.h>
 #include <fcntl.h>
 #include <unistd.h>
-#include <time.h>
 #include <errno.h>
 #include <stdarg.h>
 #include <mntent.h>
 #include <ctype.h>
 #include <poll.h>
 #include <signal.h>
-#include <sys/time.h>
 #include <libintl.h>
 #include <sys/ioctl.h>
 #include <limits.h>
@@ -111,7 +109,7 @@ struct mkfs_dev {
 };
 
 /* Number of resource groups */
-uint64_t nrgrp = 0;
+static uint64_t nrgrp = 0;
 
 struct mkfs_opts {
 	unsigned bsize;
@@ -436,8 +434,7 @@ static int opts_get(int argc, char *argv[], struct mkfs_opts *opts)
 			opts->got_uuid = 1;
 			break;
 		case 'V':
-			printf("mkfs.gfs2 %s (built %s %s)\n", VERSION,
-			       __DATE__, __TIME__);
+			printf("mkfs.gfs2 " VERSION "\n");
 			printf(REDHAT_COPYRIGHT "\n");
 			return 1;
 			break;
@@ -468,6 +465,21 @@ static int opts_get(int argc, char *argv[], struct mkfs_opts *opts)
 	return 0;
 }
 
+__attribute__((format(printf,3,4)))
+static void debug_print_ip(struct mkfs_opts *opts, struct lgfs2_inode *ip, const char *fmt, ...)
+{
+	va_list ap;
+
+	if (!opts->debug)
+		return;
+
+	va_start(ap, fmt);
+	vprintf(fmt, ap);
+	va_end(ap);
+	dinode_print(ip->i_bh->b_data);
+	printf("\n");
+}
+
 /**
  * Make sure the GFS2 is set up to use the right lock protocol
  * @lockproto: the lock protocol to mount
@@ -735,10 +747,7 @@ static int build_per_node(struct lgfs2_sbd *sdp, struct mkfs_opts *opts)
 			lgfs2_inode_put(&per_node);
 			return 1;
 		}
-		if (opts->debug) {
-			printf("\nInum Range %u:\n", j);
-			dinode_print(ip->i_bh->b_data);
-		}
+		debug_print_ip(opts, ip, "inum_range%u:", j);
 		lgfs2_inode_put(&ip);
 
 		/* coverity[identity_transfer:SUPPRESS] False positive */
@@ -749,14 +758,11 @@ static int build_per_node(struct lgfs2_sbd *sdp, struct mkfs_opts *opts)
 			lgfs2_inode_put(&per_node);
 			return 1;
 		}
-		if (opts->debug) {
-			printf("\nStatFS Change %u:\n", j);
-			dinode_print(ip->i_bh->b_data);
-		}
+		debug_print_ip(opts, ip, "statfs_change%u:", j);
 		lgfs2_inode_put(&ip);
 
 		/* coverity[identity_transfer:SUPPRESS] False positive */
-		ip = lgfs2_build_quota_change(per_node, j);
+		ip = lgfs2_build_quota_change(per_node, j, LGFS2_DEFAULT_QCSIZE);
 		if (ip == NULL) {
 			fprintf(stderr, _("Error building '%s': %s\n"), "quota_change",
 			        strerror(errno));
@@ -764,16 +770,10 @@ static int build_per_node(struct lgfs2_sbd *sdp, struct mkfs_opts *opts)
 			lgfs2_inode_put(&per_node);
 			return 1;
 		}
-		if (opts->debug) {
-			printf("\nQuota Change %u:\n", j);
-			dinode_print(ip->i_bh->b_data);
-		}
+		debug_print_ip(opts, ip, "quota_change%u:", j);
 		lgfs2_inode_put(&ip);
 	}
-	if (opts->debug) {
-		printf("\nper_node:\n");
-		dinode_print(per_node->i_bh->b_data);
-	}
+	debug_print_ip(opts, per_node, "per_node:");
 	lgfs2_inode_put(&per_node);
 	return 0;
 }
@@ -1049,10 +1049,7 @@ static int create_jindex(struct lgfs2_sbd *sdp, struct mkfs_opts *opts, struct l
 		fprintf(stderr, _("Error building '%s': %s\n"), "jindex", strerror(errno));
 		return 1;
 	}
-	if (opts->debug) {
-		printf("Jindex:\n");
-		dinode_print(jindex->i_bh->b_data);
-	}
+	debug_print_ip(opts, jindex, "jindex:");
 	lgfs2_inode_put(&jindex);
 	return 0;
 }
@@ -1091,11 +1088,7 @@ static int default_journal_size(unsigned bsize, uint64_t num_blocks)
 static int sbd_init(struct lgfs2_sbd *sdp, struct mkfs_opts *opts, unsigned bsize)
 {
 	memset(sdp, 0, sizeof(struct lgfs2_sbd));
-	sdp->sd_time = time(NULL);
 	sdp->rgtree.osi_node = NULL;
-	sdp->rgsize = opts->rgsize;
-	sdp->qcsize = opts->qcsize;
-	sdp->jsize = opts->jsize;
 	sdp->md.journals = opts->journals;
 	sdp->device_fd = opts->dev.fd;
 	sdp->sd_bsize = bsize;
@@ -1153,7 +1146,6 @@ static int sbd_init(struct lgfs2_sbd *sdp, struct mkfs_opts *opts, unsigned bsiz
 			        opts->journals, max_jsize);
 		return -1;
 	}
-	sdp->jsize = opts->jsize;
 	return 0;
 }
 
@@ -1184,9 +1176,11 @@ static int probe_contents(struct mkfs_dev *dev)
 		return 0;
 
 	if (!blkid_probe_lookup_value(pr, "TYPE", &contents, NULL)) {
-		printf(_("It appears to contain an existing filesystem (%s)\n"), contents);
+		printf(_("%s appears to contain an existing filesystem (%s)\n"),
+		       dev->path, contents);
 	} else if (!blkid_probe_lookup_value(pr, "PTTYPE", &contents, NULL)) {
-		printf(_("It appears to contain a partition table (%s).\n"), contents);
+		printf(_("%s appears to contain a partition table (%s).\n"),
+		       dev->path, contents);
 	}
 
 	if (!S_ISREG(dev->stat.st_mode)) {
@@ -1283,12 +1277,12 @@ int main(int argc, char *argv[])
 	if (opts.debug) {
 		printf(_("File system options:\n"));
 		printf("  bsize = %u\n", sbd.sd_bsize);
-		printf("  qcsize = %u\n", sbd.qcsize);
-		printf("  jsize = %u\n", sbd.jsize);
+		printf("  qcsize = %u\n", opts.qcsize);
+		printf("  jsize = %u\n", opts.jsize);
 		printf("  journals = %u\n", sbd.md.journals);
 		printf("  proto = %s\n", opts.lockproto);
 		printf("  table = %s\n", opts.locktable);
-		printf("  rgsize = %u\n", sbd.rgsize);
+		printf("  rgsize = %u\n", opts.rgsize);
 		printf("  fssize = %"PRIu64"\n", opts.fssize);
 		printf("  sunit = %lu\n", opts.sunit);
 		printf("  swidth = %lu\n", opts.swidth);
@@ -1332,10 +1326,7 @@ int main(int argc, char *argv[])
 		fprintf(stderr, _("Error building '%s': %s\n"), "master", strerror(errno));
 		exit(EXIT_FAILURE);
 	}
-	if (opts.debug) {
-		printf("Metafs inode:\n");
-		dinode_print(sbd.master_dir->i_bh->b_data);
-	}
+	debug_print_ip(&opts, sbd.master_dir, "master:");
 	sbd.sd_meta_dir = sbd.master_dir->i_num;
 
 	error = create_jindex(&sbd, &opts, mkfs_journals);
@@ -1352,28 +1343,19 @@ int main(int argc, char *argv[])
 		fprintf(stderr, _("Error building '%s': %s\n"), "inum", strerror(errno));
 		exit(EXIT_FAILURE);
 	}
-	if (opts.debug) {
-		printf("\nInum Inode:\n");
-		dinode_print(sbd.md.inum->i_bh->b_data);
-	}
+	debug_print_ip(&opts, sbd.md.inum, "inum:");
 	sbd.md.statfs = lgfs2_build_statfs(&sbd);
 	if (sbd.md.statfs == NULL) {
 		fprintf(stderr, _("Error building '%s': %s\n"), "statfs", strerror(errno));
 		exit(EXIT_FAILURE);
 	}
-	if (opts.debug) {
-		printf("\nStatFS Inode:\n");
-		dinode_print(sbd.md.statfs->i_bh->b_data);
-	}
+	debug_print_ip(&opts, sbd.md.statfs, "statfs:");
 	ip = lgfs2_build_rindex(&sbd);
 	if (ip == NULL) {
 		fprintf(stderr, _("Error building '%s': %s\n"), "rindex", strerror(errno));
 		exit(EXIT_FAILURE);
 	}
-	if (opts.debug) {
-		printf("\nResource Index:\n");
-		dinode_print(ip->i_bh->b_data);
-	}
+	debug_print_ip(&opts, ip, "rindex:");
 	lgfs2_inode_put(&ip);
 	if (!opts.quiet) {
 		printf("%s", _("Creating quota file: "));
@@ -1384,10 +1366,7 @@ int main(int argc, char *argv[])
 		fprintf(stderr, _("Error building '%s': %s\n"), "quota", strerror(errno));
 		exit(EXIT_FAILURE);
 	}
-	if (opts.debug) {
-		printf("\nQuota:\n");
-		dinode_print(ip->i_bh->b_data);
-	}
+	debug_print_ip(&opts, ip, "quota:");
 	lgfs2_inode_put(&ip);
 	if (!opts.quiet)
 		printf("%s", _("Done\n"));
@@ -1397,10 +1376,7 @@ int main(int argc, char *argv[])
 		sbd.md.rooti->i_flags |= GFS2_DIF_INHERIT_JDATA;
 		lgfs2_dinode_out(sbd.md.rooti, sbd.md.rooti->i_bh->b_data);
 	}
-	if (opts.debug) {
-		printf("\nRoot directory:\n");
-		dinode_print(sbd.md.rooti->i_bh->b_data);
-	}
+	debug_print_ip(&opts, sbd.md.rooti, "root:");
 	sbd.sd_root_dir = sbd.md.rooti->i_num;
 
 	strncpy(sbd.sd_lockproto, opts.lockproto, GFS2_LOCKNAME_LEN - 1);
@@ -1410,12 +1386,13 @@ int main(int argc, char *argv[])
 
 	lgfs2_init_inum(&sbd);
 	if (opts.debug)
-		printf("\nNext Inum: %"PRIu64"\n", sbd.md.next_inum);
+		printf("Next inum: %"PRIu64"\n", sbd.md.next_inum);
 
 	lgfs2_init_statfs(&sbd, &sc);
 	if (opts.debug) {
-		printf("\nStatfs:\n");
+		printf("Statfs:\n");
 		statfs_change_print(&sc);
+		printf("\n");
 	}
 	lgfs2_inode_put(&sbd.md.rooti);
 	lgfs2_inode_put(&sbd.master_dir);
