@@ -10,25 +10,21 @@
 #include <string.h>
 #include <libintl.h>
 #define _(String) gettext(String)
-#include <linux_endian.h>
-#include <linux/gfs2_ondisk.h>
-#include "tunegfs2.h"
-
-#ifdef GFS2_HAS_UUID
+#include <libgfs2.h>
 #include <uuid.h>
-#endif
+#include "tunegfs2.h"
 
 int read_super(struct tunegfs2 *tfs)
 {
 	void *block;
 	int n;
        	tfs->sb_start = GFS2_SB_ADDR << GFS2_BASIC_BLOCK_SHIFT;
-	block = malloc(sizeof(char) * GFS2_DEFAULT_BSIZE);
+	block = malloc(sizeof(char) * LGFS2_DEFAULT_BSIZE);
 	if (!block) {
 		perror("read_super: malloc");
 		return EX_UNAVAILABLE;
 	}
-	n = pread(tfs->fd, block, GFS2_DEFAULT_BSIZE, tfs->sb_start);
+	n = pread(tfs->fd, block, LGFS2_DEFAULT_BSIZE, tfs->sb_start);
 	if (n < 0) {
 		perror("read_super: pread");
 		free(block);
@@ -54,21 +50,18 @@ static int is_gfs2(const struct tunegfs2 *tfs)
 
 int print_super(const struct tunegfs2 *tfs)
 {
-	printf(_("File system volume name: %s\n"), tfs->sb->sb_locktable);
-#ifdef GFS2_HAS_UUID
-	{
 	char readable_uuid[36+1];
 
 	uuid_unparse(tfs->sb->sb_uuid, readable_uuid);
+	printf(_("File system volume name: %s\n"), tfs->sb->sb_locktable);
 	printf(_("File system UUID: %s\n"), readable_uuid);
-	}
-#endif
 	printf( _("File system magic number: 0x%X\n"), be32_to_cpu(tfs->sb->sb_header.mh_magic));
+	printf(_("File system format version: %"PRIu32"\n"), be32_to_cpu(tfs->sb->sb_fs_format));
 	printf(_("Block size: %d\n"), be32_to_cpu(tfs->sb->sb_bsize));
 	printf(_("Block shift: %d\n"), be32_to_cpu(tfs->sb->sb_bsize_shift));
-	printf(_("Root inode: %llu\n"), (unsigned long long)be64_to_cpu(tfs->sb->sb_root_dir.no_addr));
+	printf(_("Root inode: %"PRIu64"\n"), be64_to_cpu(tfs->sb->sb_root_dir.no_addr));
 	if (is_gfs2(tfs))
-		printf(_("Master inode: %llu\n"), (unsigned long long)be64_to_cpu(tfs->sb->sb_master_dir.no_addr));
+		printf(_("Master inode: %"PRIu64"\n"), be64_to_cpu(tfs->sb->sb_master_dir.no_addr));
 	printf(_("Lock protocol: %s\n"), tfs->sb->sb_lockproto);
 	printf(_("Lock table: %s\n"), tfs->sb->sb_locktable);
 
@@ -78,7 +71,7 @@ int print_super(const struct tunegfs2 *tfs)
 int write_super(const struct tunegfs2 *tfs)
 {
 	int n;
-	n = pwrite(tfs->fd, tfs->sb, GFS2_DEFAULT_BSIZE, tfs->sb_start);
+	n = pwrite(tfs->fd, tfs->sb, LGFS2_DEFAULT_BSIZE, tfs->sb_start);
 	if (n < 0) {
 		perror("write_super: pwrite");
 		return EX_IOERR;
@@ -88,7 +81,6 @@ int write_super(const struct tunegfs2 *tfs)
 
 int change_uuid(struct tunegfs2 *tfs, const char *str)
 {
-#ifdef GFS2_HAS_UUID
 	uuid_t uuid;
 	int status;
 
@@ -96,10 +88,6 @@ int change_uuid(struct tunegfs2 *tfs, const char *str)
 	if (status == 0)
 		uuid_copy(tfs->sb->sb_uuid, uuid);
 	return status;
-#else
-	fprintf(stderr, _("UUID support unavailable in this build\n"));
-	return 1;
-#endif
 }
 
 int change_lockproto(struct tunegfs2 *tfs, const char *lockproto)
@@ -150,3 +138,21 @@ int change_locktable(struct tunegfs2 *tfs, const char *locktable)
 	return 0;
 }
 
+int change_format(struct tunegfs2 *tfs, const char *format)
+{
+	char *end;
+	long ln;
+
+	errno = 0;
+	ln = strtol(format, &end, 10);
+	if (errno || end == format || !LGFS2_FS_FORMAT_VALID(ln)) {
+		fprintf(stderr, _("Invalid format option '%s'\n"), format);
+		return EX_DATAERR;
+	}
+	if (ln < be32_to_cpu(tfs->sb->sb_fs_format)) {
+		fprintf(stderr, _("Regressing the filesystem format is not supported\n"));
+		return EX_DATAERR;
+	}
+	tfs->sb->sb_fs_format = cpu_to_be32(ln);
+	return 0;
+}
